def test(verbose=True):
    r"""Run tests to verify this package's integrity. (DEPRECATED)

    Parameters
    ----------
    verbose : bool
        ``True`` to show diagnostic. Defaults to ``True``.

    Returns
    -------
    int
        Exit code: ``0`` for success.
    """

    return 0
